diff --git a/contents/code/tilelist.js b/contents/code/tilelist.js
index a95f11fef4753e12562d5126483f3606e349b921..0cc0e72d3e9e302728abf27825ee79e525769256 100644
--- a/contents/code/tilelist.js
+++ b/contents/code/tilelist.js
@@ -336,9 +336,12 @@ TileList._isIgnored = function(client) {
 		return true;
 	}
 	// HACK: Steam doesn't set the windowtype properly
 	// Everything that isn't captioned "Steam" should be a dialog - these resize worse thant the main window does
 	if (client.resourceClass.toString() == "steam" && client.caption != "Steam") {
 		return true;
+	} else if (client.resourceClass.toString() != "steam" && client.caption == "Steam") {
+		return true;
 	}
 	if (client.specialWindow == true) {
 		return true;
@@ -336,9 +336,12 @@ TileList._isIgnored = function(client) {
 	}
 	// HACK: Steam doesn't set the windowtype properly
-	// Everything that isn't captioned "Steam" should be a dialog - these resize worse thant the main window does
+	// Everything that isn't captioned "Steam" should be a dialog - these resize worse than the main window does
+	// With the exception of course of the class-less update/start dialog with the caption "Steam" (*Sigh*)
 	if (client.resourceClass.toString() == "steam" && client.caption != "Steam") {
 		return true;